/*
**
**  WAY (Where Are You ?)
**
**  config.h		configuration template module.
**
**  Author: Roberto Bagnara (bagnara@vxcern.cern.ch),
**          CERN  DD Division OC Group RA Section.
**
**  All rights reserved to:
**
**          CERN
**          European Laboratory for Particle Physics
**          CH 1211 Geneva 23
**          SWITZERLAND
**
**  Permission is granted to any individual or institution
**  to use, copy, or redistribute this software so long as
**  it  is not  sold for  profit, provided  this copyright
**  notice is retained.
**
**  Modification History:
**
**  Version  Date    Who              Comments
**
**  1.0.00   890728  Roberto Bagnara  First working version
**
**
**  Description:
**
**  this module contains definitions for all the configuration informations
**  needed by the WAY name server.
**
*/

/* Control the VMS conditionals. */

#ifdef vms
#ifndef VMS
#define VMS
#endif
#endif

/* If compiled with GNU C, use the built-in alloca */

#ifdef __GNUC__
#define alloca(n) __builtin_alloca(n)
#endif

/*
**	Define HAS_FILE_IO if the name server is intended to run
**	on a machine with file I/O capability. If this macro is
**	defined the name server will be able to initialize its
**	database from a file, to save it, to write a log file etc.
*/

#define HAS_FILE_IO

/*
**	Define DEFAULT_DBASE_FILE as a character string containing
**	the default pathname for the name server database file.
**	This is the default file name that the name server (if
**	HAS_FILE_IO has been defined) will read at bootstrap time
**	(and when required to do so) to initialize its database.
**	The name server will also update that file on request.
*/

#define DEFAULT_DBASE_FILE "/usr/users/stud/bagnara/way/nsfile"

/*
**	Define DBASE_TMP_PATH as a character string containing the
**	pathname for the name server temporary database file. The
**	character string must be such that appending to it a file
**	name (without directory info) will result in a complete
**	file identifier.
*/

#define TMP_DBASE_PATH "/tmp/"

/*
**	Define DEFAULT_LOG_FILE as a character string containing the
**	pathname for the log file the name server will write into.
*/

#define DEFAULT_LOG_FILE "/usr/users/stud/bagnara/way/WAYLOG"

/*
**	Arguments to use with exit.
**
*/

#ifdef VMS
#define SUCCESS_EXIT_CODE 1
#define FATAL_EXIT_CODE (44 | 0x10000000)  /* Failure, and no DCL message.  */
#else
#define SUCCESS_EXIT_CODE 0
#define FATAL_EXIT_CODE 1
#endif

